package com.huashe.park.application.web.controller.cons;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.huashe.common.domain.AjaxResult;
import com.huashe.park.core.service.IConsPileHoleInfoService;
import com.huashe.park.domain.entity.ConsPileHoleInfo;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 施工桩点信息Controller
 * 
 * @author ruoyi
 * @date 2025-02-13
 */
@RestController
@RequestMapping("/cons/pileHoleInfo")
public class ConsPileHoleInfoController extends BaseController
{
    @Autowired
    private IConsPileHoleInfoService consPileHoleInfoService;

    /**
     * 查询施工桩点信息列表
     */
    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(ConsPileHoleInfo consPileHoleInfo)
    {
        startPage();
        List<ConsPileHoleInfo> list = consPileHoleInfoService.selectConsPileHoleInfoList(consPileHoleInfo);
        return getDataTable(list);
    }

    /**
     * 导出施工桩点信息列表
     */
    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:export')")
    @Log(title = "施工桩点信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ConsPileHoleInfo consPileHoleInfo)
    {
        List<ConsPileHoleInfo> list = consPileHoleInfoService.selectConsPileHoleInfoList(consPileHoleInfo);
        ExcelUtil<ConsPileHoleInfo> util = new ExcelUtil<ConsPileHoleInfo>(ConsPileHoleInfo.class);
        util.exportExcel(response, list, "施工桩点信息数据");
    }

    /**
     * 获取施工桩点信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(consPileHoleInfoService.selectConsPileHoleInfoById(id));
    }

    /**
     * 新增施工桩点信息
     */
    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:add')")
    @Log(title = "施工桩点信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ConsPileHoleInfo consPileHoleInfo)
    {
        return toAjax(consPileHoleInfoService.insertConsPileHoleInfo(consPileHoleInfo));
    }

    /**
     * 修改施工桩点信息
     */
    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:edit')")
    @Log(title = "施工桩点信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ConsPileHoleInfo consPileHoleInfo)
    {
        return toAjax(consPileHoleInfoService.updateConsPileHoleInfo(consPileHoleInfo));
    }

    /**
     * 删除施工桩点信息
     */
    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:remove')")
    @Log(title = "施工桩点信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(consPileHoleInfoService.deleteConsPileHoleInfoByIds(ids));
    }
}
