package com.ruoyi.ems.controller;

import com.huashe.common.domain.AjaxResult;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.ems.domain.EmsObjAttrValue;
import com.ruoyi.ems.service.IEmsObjAttrValueService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 能源对象属性值Controller
 *
 * @author ruoyi
 * @date 2024-09-25
 */
@RestController
@RequestMapping("/object/attr/value")
@Api(value = "EmsObjAttrValueController", description = "能源对象属性值管理")
public class EmsObjAttrValueController extends BaseController {
    @Autowired
    private IEmsObjAttrValueService objAttrValueService;

    /**
     * 查询能源对象属性值列表
     */
    @GetMapping("/list")
    public AjaxResult list(EmsObjAttrValue objAttrValue) {
        List<EmsObjAttrValue> list = objAttrValueService.selectObjAttrValueList(objAttrValue);
        return success(list);
    }

    /**
     * 获取能源对象属性值详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(objAttrValueService.selectObjAttrValueById(id));
    }

    /**
     * 新增能源对象属性值
     */
    @Log(title = "能源对象属性值", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmsObjAttrValue EmsObjAttrValue) {
        return toAjax(objAttrValueService.insertObjAttrValue(EmsObjAttrValue));
    }

    /**
     * 新增能源对象属性值
     */
    @Log(title = "能源对象属性值", businessType = BusinessType.INSERT)
    @PostMapping("/batch")
    public AjaxResult addBatch(@RequestBody List<EmsObjAttrValue> list) {
        return toAjax(objAttrValueService.insertBatch(list));
    }

    /**
     * 修改能源对象属性值
     */
    @Log(title = "能源对象属性值", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmsObjAttrValue EmsObjAttrValue) {
        return toAjax(objAttrValueService.updateObjAttrValue(EmsObjAttrValue));
    }

    /**
     * 删除能源对象属性值
     */
    @Log(title = "能源对象属性值", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(objAttrValueService.deleteObjAttrValueByIds(ids));
    }

    /**
     * 删除能源对象属性值
     */
    @Log(title = "能源对象属性值", businessType = BusinessType.DELETE)
    @DeleteMapping("/deleteByObj")
    public AjaxResult removeByObj(@RequestParam(name = "objType") Integer objType,
        @RequestParam(name = "objCode") String objCode) {
        return toAjax(objAttrValueService.deleteByObjCode(objType, objCode));
    }
}
